@@ -1,6 +1,4 @@
 """The InfimaClient is used to interact with the infima platform."""
-
-import datetime
 import os
 import re
 import ssl
@@ -16,6 +14,7 @@ from attr import define, field
 import infima_client.extras
 from infima_client.api import ServiceAPI
 from infima_client.demo import demo
+from infima_client.extras.utils import DateT
 from infima_client.version import __version__
 
 TOKEN = os.environ.get("INFIMA_TOKEN", None)
@@ -29,7 +28,7 @@ class InfimaWarning(Warning):
     pass
 
 
-@define(auto_attribs=True)
+@define(auto_attribs=True, slots=False)
 class InfimaClient:
     """A class for keeping track of data related to the API"""
 
@@ -73,7 +72,7 @@ class InfimaClient:
         try:
             with httpx.Client() as client:
                 version = client.get(urljoin(self.base_url, "info")).json()["version"]
-        except:
+        except Exception:
             pass
         return version
 
@@ -112,7 +111,7 @@ class InfimaClient:
     def get_predictions(
         self,
         symbols: List[str],
-        as_of: Optional[datetime.date] = None,
+        as_of: Optional[DateT] = None,
         col: Optional[str] = "cpr",
         wide: bool = True,
         progress: bool = True,
@@ -129,8 +128,8 @@ class InfimaClient:
     def get_pool_actuals(
         self,
         cusips: List[str],
-        start: Optional[datetime.date] = None,
-        end: Optional[datetime.date] = None,
+        start: Optional[DateT] = None,
+        end: Optional[DateT] = None,
         col: Optional[str] = "cpr",
         wide: bool = True,
         progress: bool = True,
@@ -148,8 +147,8 @@ class InfimaClient:
     def get_cohort_actuals(
         self,
         cohorts: List[str],
-        start: Optional[datetime.date] = None,
-        end: Optional[datetime.date] = None,
+        start: Optional[DateT] = None,
+        end: Optional[DateT] = None,
         col: Optional[str] = "cpr",
         wide: bool = True,
         progress: bool = True,
@@ -164,6 +163,25 @@ class InfimaClient:
             progress=progress,
         )
 
+    def get_actuals(
+        self,
+        symbols: List[str],
+        start: Optional[DateT] = None,
+        end: Optional[DateT] = None,
+        col: Optional[str] = "cpr",
+        wide: bool = True,
+        progress: bool = True,
+    ) -> Optional[pd.DataFrame]:
+        return infima_client.extras.get_actuals(
+            client=self,
+            symbols=symbols,
+            start=start,
+            end=end,
+            col=col,
+            wide=wide,
+            progress=progress,
+        )
+
     def check_cohort_coverage(self, cohorts: List[str]) -> Optional[pd.DataFrame]:
         return infima_client.extras.check_cohort_coverage(client=self, cohorts=cohorts)
 
@@ -173,7 +191,7 @@ class InfimaClient:
     def get_cohort_summary(
         self,
         cohorts: List[str],
-        factor_date: Optional[datetime.date] = None,
+        factor_date: Optional[DateT] = None,
     ) -> Optional[pd.DataFrame]:
         return infima_client.extras.get_cohort_summary(
             client=self, cohorts=cohorts, factor_date=factor_date
@@ -181,3 +199,10 @@ class InfimaClient:
 
     def get_pool_attributes(self, cusips: List[str]) -> Optional[pd.DataFrame]:
         return infima_client.extras.get_pool_attributes(client=self, cusips=cusips)
+
+    def get_member_lists(
+        self, cohorts: List[str], factor_date: Optional[DateT] = None
+    ) -> Optional[Dict[str, List[str]]]:
+        return infima_client.extras.get_member_lists(
+            client=self, cohorts=cohorts, factor_date=factor_date
+        )
