@@ -1,13 +1,16 @@
-from .actuals import get_cohort_actuals, get_pool_actuals
+from .actuals import get_actuals, get_cohort_actuals, get_pool_actuals
 from .attributes import get_cohort_summary, get_pool_attributes
+from .cohorts import get_member_lists
 from .coverage import check_cohort_coverage, check_coverage
 from .predictions import get_predictions
 
 __all__ = [
     "check_cohort_coverage",
     "check_coverage",
+    "get_actuals",
     "get_cohort_actuals",
     "get_cohort_summary",
+    "get_member_lists",
     "get_pool_actuals",
     "get_pool_attributes",
     "get_predictions",
